summaryrefslogtreecommitdiff
path: root/sql/item_timefunc.cc
diff options
context:
space:
mode:
Diffstat (limited to 'sql/item_timefunc.cc')
-rw-r--r--sql/item_timefunc.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/sql/item_timefunc.cc b/sql/item_timefunc.cc
index 4f1d6c5d63e..46d39b4ced6 100644
--- a/sql/item_timefunc.cc
+++ b/sql/item_timefunc.cc
@@ -1797,9 +1797,9 @@ void Item_char_typecast::print(String *str)
{
str->append('(');
char buffer[20];
- // latin1 is good enough for numbers
- String st(buffer, sizeof(buffer), &my_charset_latin1);
- st.set((ulonglong)cast_length, &my_charset_latin1);
+ // my_charset_bin is good enough for numbers
+ String st(buffer, sizeof(buffer), &my_charset_bin);
+ st.set((ulonglong)cast_length, &my_charset_bin);
str->append(st);
str->append(')');
}